@@ -191,7 +191,7 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
   NNEW(fext,double,neq[0]);
 
   if(*iperturb==0){
-    FORTRAN(mafillsm,(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
+    mafillsmmain(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
 	      ipompc,nodempc,coefmpc,nmpc,nodeforc,ndirforc,xforc,
 	      nforc,nelemload,sideload,xload,nload,xbody,ipobody,nbody,cgr,
 	      ad,au,fext,nactdof,icol,jq,irow,neq,nzl,nmethod,
@@ -206,10 +206,10 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
 	      ibody,xloadold,&reltime,veold,springarea,nstate_,
 	      xstateini,xstate,thicke,integerglob,doubleglob,
 	      tieset,istartset,iendset,ialset,&ntie,&nasym,pslavsurf,pmastsurf,
-	      &mortar,clearini,ielprop,prop,&ne0,fnext,&kscale));
+	      &mortar,clearini,ielprop,prop,&ne0,fnext,&kscale);
   }
   else{
-    FORTRAN(mafillsm,(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
+    mafillsmmain(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
 	      ipompc,nodempc,coefmpc,nmpc,nodeforc,ndirforc,xforc,
 	      nforc,nelemload,sideload,xload,nload,xbody,ipobody,nbody,cgr,
 	      ad,au,fext,nactdof,icol,jq,irow,neq,nzl,nmethod,
@@ -224,7 +224,7 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
 	      ibody,xloadold,&reltime,veold,springarea,nstate_,
               xstateini,xstate,thicke,integerglob,doubleglob,
 	      tieset,istartset,iendset,ialset,&ntie,&nasym,pslavsurf,
-	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale));
+	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale);
   }
 
   /* determining the right hand side */
@@ -395,7 +395,7 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
   NNEW(fext,double,neq[0]);
 
   if(*iperturb==0){
-    FORTRAN(mafillsm,(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
+      mafillsmmain(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
 	      ipompc,nodempc,coefmpc,nmpc,nodeforc,ndirforc,xforc,
 	      nforc,nelemload,sideload,xload,nload,xbody,ipobody,nbody,cgr,
 	      ad,au,fext,nactdof,icol,jq,irow,neq,nzl,nmethod,
@@ -410,10 +410,10 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
 	      ibody,xloadold,&reltime,veold,springarea,nstate_,
               xstateini,xstate,thicke,integerglob,doubleglob,
 	      tieset,istartset,iendset,ialset,&ntie,&nasym,pslavsurf,
-	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale));
+	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale);
   }
   else{
-    FORTRAN(mafillsm,(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
+      mafillsmmain(co,nk,kon,ipkon,lakon,ne,nodeboun,ndirboun,xboun,nboun,
 	      ipompc,nodempc,coefmpc,nmpc,nodeforc,ndirforc,xforc,
 	      nforc,nelemload,sideload,xload,nload,xbody,ipobody,nbody,cgr,
 	      ad,au,fext,nactdof,icol,jq,irow,neq,nzl,nmethod,
@@ -428,7 +428,7 @@ void arpackbu(double *co, ITG *nk, ITG *kon, ITG *ipkon, char *lakon,
 	      ibody,xloadold,&reltime,veold,springarea,nstate_,
               xstateini,xstate,thicke,integerglob,doubleglob,
 	      tieset,istartset,iendset,ialset,&ntie,&nasym,pslavsurf,
-	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale));
+	      pmastsurf,&mortar,clearini,ielprop,prop,&ne0,fnext,&kscale);
   }
 
   SFREE(stx);SFREE(fext);if(*nbody>0) SFREE(ipobody);
