@@ -39,11 +39,11 @@
       character*20 sideload(*)
       character*80 matname(*),amat
 !
-      integer mi(*),nk,konl(20),ielmat(mi(3),*),nbody,ifaceq(9,6),
+      integer mi(*),nk,konl(20),ielmat(mi(3),*),nbody,ifaceq(8,6),
      &  nelemload(2,*),ielprop(*),null,
      &  nelem,nmethod,iperturb,nload,idist,i,i1,j1,jj,jj1,id,kk,
      &  ipointer,nope,nopes,j,k,ntmat_,i2,imat,ii,ig,mint2d,mint3d,
-     &  ifacet(7,4),ifacew(8,5),istep,iinc,layer,kspt,jltyp,iflag,
+     &  ifacet(6,4),ifacew(8,5),istep,iinc,layer,kspt,jltyp,iflag,
      &  ipompc(*),nodempc(3,*),nmpc,ikmpc(*),ilmpc(*),iscale
 !
       real*8 co(3,*),p1(3,2),p2(3,2),omx(2),bodyfx(3),veold(0:mi(2),*),
@@ -56,16 +56,16 @@
 !
       include "gauss.f"
 !
-      data ifaceq /4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/
-      data ifacet /1,3,2,7,6,5,11,
-     &             1,2,4,5,9,8,12,
-     &             2,3,4,6,10,9,13,
-     &             1,4,3,8,10,7,14/
+      data ifaceq /4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/
+      data ifacet /1,3,2,7,6,5,
+     &             1,2,4,5,9,8,
+     &             2,3,4,6,10,9,
+     &             1,4,3,8,10,7/
       data ifacew /1,3,2,9,8,7,0,0,
      &             4,5,6,10,11,12,0,0,
      &             1,2,5,4,7,14,10,13,
