@@ -51,23 +51,23 @@
       character*80 matname(*),amat
       character*81 tieset(3,*)
 !
-      integer konl(26),ifaceq(9,6),nelemload(2,*),nbody,nelem,
+      integer konl(26),ifaceq(8,6),nelemload(2,*),nbody,nelem,
      &  mi(*),iloc,jfaces,igauss,mortar,kon(*),ielprop(*),null,
      &  mattyp,ithermal,iperturb(*),nload,idist,i,j,k,l,i1,i2,j1,
      &  nmethod,k1,l1,ii,jj,ii1,jj1,id,ipointer,ig,m1,m2,m3,m4,kk,
      &  nelcon(2,*),nrhcon(*),nalcon(2,*),ielmat(mi(3),*),six,
      &  ielorien(mi(3),*),ilayer,nlayer,ki,kl,ipkon(*),indexe,
      &  ntmat_,nope,nopes,norien,ihyper,iexpl,kode,imat,mint2d,
-     &  mint3d,ifacet(7,4),nopev,iorien,istiff,ncmat_,iface,
+     &  mint3d,ifacet(6,4),nopev,iorien,istiff,ncmat_,iface,
      &  ifacew(8,5),intscheme,n,ipointeri,ipointerj,istep,iinc,
      &  layer,kspt,jltyp,iflag,iperm(60),m,ipompc(*),nodempc(3,*),
      &  nmpc,ikmpc(*),ilmpc(*),iscale,nstate_,ne0,iselect(6),
      &  istartset(*),iendset(*),ialset(*),ntie,integerglob(*),nasym,
      &  nplicon(0:ntmat_,*),nplkcon(0:ntmat_,*),npmat_,nopered,
-     &  ndesi,nodedesi(*),ndirdesi(*),desvar,actnode,kscale
+     &  ndesi,nodedesi(*),ndirdesi(*),idesva,iactnod,kscale
 !
       real*8 co(3,*),xl(3,26),shp(4,26),xs2(3,7),veold(0:mi(2),*),
-     &  s(100,100),sf(100,100),w(3,3),p1(3),p2(3),bodyf(3),bodyfx(3),
+     &  s(100,100),w(3,3),p1(3),p2(3),bodyf(3),bodyfx(3),
      &  ff(100),bf(3),q(3),shpj(4,26),elcon(0:ncmat_,ntmat_,*),t(3),
      &  rhcon(0:1,ntmat_,*),xkl(3,3),eknlsign,reltime,prop(*),
      &  alcon(0:6,ntmat_,*),alzero(*),orab(7,*),t0(*),t1(*),
@@ -106,16 +106,16 @@
 !
       include "gauss.f"
 !
-      ifaceq=reshape((/4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/),(/9,6/))
-      ifacet=reshape((/1,3,2,7,6,5,11,
-     &             1,2,4,5,9,8,12,
-     &             2,3,4,6,10,9,13,
-     &             1,4,3,8,10,7,14/),(/7,4/))
+      ifaceq=reshape((/4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/),(/8,6/))
+      ifacet=reshape((/1,3,2,7,6,5,
+     &             1,2,4,5,9,8,
+     &             2,3,4,6,10,9,
+     &             1,4,3,8,10,7/),(/6,4/))
       ifacew=reshape((/1,3,2,9,8,7,0,0,
      &             4,5,6,10,11,12,0,0,
      &             1,2,5,4,7,14,10,13,
@@ -145,14 +145,6 @@ c     Bernhardi end
          nope=20
          nopev=8
          nopes=8
-      elseif(lakonl(4:4).eq.'2') then
-!
-!        nopes for C3D26 is a default value which can be overwritten
-!        while integrating over the element faces
-!
-         nope=26
-         nopev=8
-         nopes=8
       elseif(lakonl(4:4).eq.'8') then
          nope=8
          nopev=8
@@ -161,14 +153,6 @@ c     Bernhardi end
          nope=10
          nopev=4
          nopes=6
-      elseif(lakonl(4:5).eq.'14') then
-!
-!        nopes for C3D14 is a default value which can be overwritten
-!        while integrating over the element faces
-!
-         nope=14
-         nopev=4
-         nopes=6
       elseif(lakonl(4:4).eq.'4') then
          nope=4
          nopev=4
@@ -263,10 +247,9 @@ c     Bernhardi end
                call beamintscheme(lakonl,mint3d,ielprop(nelem),prop,
      &              null,xi,et,ze,weight)
             endif
-         elseif((lakonl(4:4).eq.'8').or.(lakonl(4:6).eq.'20R').or.
-     &          (lakonl(4:6).eq.'26R')) then
-            if(((lakonl(7:7).eq.'A').or.(lakonl(7:7).eq.'S').or.
-     &         (lakonl(7:7).eq.'E')).and.(lakonl(4:6).ne.'26R')) then
+         elseif((lakonl(4:4).eq.'8').or.(lakonl(4:6).eq.'20R')) then
+            if((lakonl(7:7).eq.'A').or.(lakonl(7:7).eq.'S').or.
+     &         (lakonl(7:7).eq.'E')) then
                mint2d=2
                mint3d=4
             else
@@ -280,7 +263,7 @@ c     Bernhardi end
          elseif(lakonl(4:4).eq.'2') then
             mint2d=9
             mint3d=27
-         elseif((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14')) then
+         elseif(lakonl(4:5).eq.'10') then
             mint2d=3
             mint3d=4
          elseif(lakonl(4:4).eq.'4') then
@@ -309,10 +292,9 @@ c     Bernhardi end
                   mint2d=9
                endif
             endif
-         elseif((lakonl(4:5).eq.'10').or.(lakonl(4:4).eq.'4').or.
-     &          (lakonl(4:5).eq.'14')) then
+         elseif((lakonl(4:5).eq.'10').or.(lakonl(4:4).eq.'4')) then
             mint3d=15
-            if((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14')) then
+            if(lakonl(4:5).eq.'10') then
                mint2d=3
             else
                mint2d=1
@@ -367,7 +349,7 @@ c     Bernhardi end
 !     the stiffness matrix
 !     -------------------------------------------------------------
 !
-      do desvar=0,ndesi
+      do idesva=0,ndesi
 !     Ertl end
 !
 !     initialisation of the local coordinates
@@ -375,6 +357,7 @@ c     Bernhardi end
       do i=1,nope
         konl(i)=kon(indexe+i)
         do j=1,3
+           voldl(j,i)=vold(j,konl(i))
           xl(j,i)=co(j,konl(i))
         enddo
       enddo
@@ -383,11 +366,11 @@ c     Bernhardi end
 !     if the designnode belongs to the considered element
 !
 !     Ertl end
-      if(desvar.gt.0) then 
+      if(idesva.gt.0) then 
          do i=1,nope
-            actnode=kon(indexe+i)
-            if(actnode.eq.nodedesi(desvar)) then
-               xl(ndirdesi(desvar),i)=xl(ndirdesi(desvar),i)+distmin
+            iactnod=kon(indexe+i)
+            if(iactnod.eq.nodedesi(idesva)) then
+               xl(ndirdesi(idesva),i)=xl(ndirdesi(idesva),i)+distmin
                exit
             endif
          enddo
@@ -412,6 +395,12 @@ c     Bernhardi end
         enddo
       enddo
 !
+!     initialisation of ff
+!
+      do i=1,3*nope
+         ff(i)=0.d0
+      enddo
+!
 !     calculating the stiffness matrix for the contact spring elements
 !
       if(mint3d.eq.0) then
@@ -484,8 +473,7 @@ c     Bernhardi end
                   call beamintscheme(lakonl,mint3d,ielprop(nelem),prop,
      &                 kk,xi,et,ze,weight)
                endif
-            elseif((lakonl(4:4).eq.'8').or.(lakonl(4:6).eq.'20R').or.
-     &             (lakonl(4:6).eq.'26R')) 
+            elseif((lakonl(4:4).eq.'8').or.(lakonl(4:6).eq.'20R')) 
      &              then
                if(lakonl(7:8).ne.'LC') then
                   xi=gauss3d2(1,kk)
@@ -537,7 +525,7 @@ c     Bernhardi end
                et=gauss3d3(2,kk)
                ze=gauss3d3(3,kk)
                weight=weight3d3(kk)
-            elseif((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14')) then
+            elseif(lakonl(4:5).eq.'10') then
                xi=gauss3d5(1,kk)
                et=gauss3d5(2,kk)
                ze=gauss3d5(3,kk)
@@ -600,14 +588,10 @@ c     Bernhardi end
             else
                call shape20h(xi,et,ze,xl,xsj,shp,iflag)
             endif
-         elseif(nope.eq.26) then
-            call shape26h(xi,et,ze,xl,xsj,shp,iflag,konl)
          elseif(nope.eq.8) then
             call shape8h(xi,et,ze,xl,xsj,shp,iflag)
          elseif(nope.eq.10) then
             call shape10tet(xi,et,ze,xl,xsj,shp,iflag)
-         elseif(nope.eq.14) then
-            call shape14tet(xi,et,ze,xl,xsj,shp,iflag,konl)
          elseif(nope.eq.4) then
             call shape4tet(xi,et,ze,xl,xsj,shp,iflag)
          elseif(nope.eq.15) then
@@ -651,7 +635,7 @@ c         if((iperturb(1).ne.0).and.stiffness.and.(.not.buckling))
                   t0l=t0l+t0(konl(i1))/8.d0
                   t1l=t1l+t1(konl(i1))/8.d0
                enddo
-            elseif((lakonl(4:6).eq.'20 ').or.(lakonl(4:6).eq.'26 '))then
+            elseif(lakonl(4:6).eq.'20 ')then
                nopered=20
                call lintemp(t0,t1,konl,nopered,kk,t0l,t1l)
             else
@@ -666,7 +650,7 @@ c         if((iperturb(1).ne.0).and.stiffness.and.(.not.buckling))
                   t0l=t0l+t0(konl(i1))/8.d0
                   t1l=t1l+vold(0,konl(i1))/8.d0
                enddo
-            elseif((lakonl(4:6).eq.'20 ').or.(lakonl(4:6).eq.'26 '))then
+            elseif(lakonl(4:6).eq.'20 ')then
                nopered=20
                call lintemp_th(t0,vold,konl,nopered,kk,t0l,t1l,mi)
             else
@@ -1139,21 +1123,6 @@ c                     if(iperturb(1).eq.0) then
 c            read(sideload(id)(2:2),'(i1)') ig
             ig=ichar(sideload(id)(2:2))-48
 !
-!           check whether 8 or 9-nodes face
-!
-            if(nope.eq.26) then
-               if(konl(20+ig).eq.konl(20)) then
-                  nopes=8
-               else
-                  nopes=9
-               endif
-            elseif(nope.eq.14) then
-               if(konl(10+ig).eq.konl(10)) then
-                  nopes=6
-               else
-                  nopes=7
-               endif
-            endif
 !
 !         treatment of wedge faces
 !
@@ -1176,7 +1145,7 @@ c            read(sideload(id)(2:2),'(i1)') ig
           endif
 !
 c     Bernhardi start
-          if((nope.eq.26).or.(nope.eq.20).or.(nope.eq.8).or.
+          if((nope.eq.20).or.(nope.eq.8).or.
      &       (nope.eq.11)) then
 c     Bernhardi end
 c             if(iperturb(1).eq.0) then
@@ -1201,6 +1170,22 @@ c             if(iperturb(1).eq.0) then
                    enddo
                 enddo
              endif
+!
+!         ---------------------------------------------------------
+!         variation of xl2 and xl1 (quads) for sensitivity analysis
+!         ---------------------------------------------------------
+!
+          if(idesva.gt.0) then
+             do i=1,nopes
+                iactnod=konl(ifaceq(i,ig))
+                if(iactnod.eq.nodedesi(idesva)) then
+                   xl2(ndirdesi(idesva),i)=
+     &                  xl2(ndirdesi(idesva),i)+distmin
+                   exit
+                endif
+             enddo
+          endif     
+!     
           elseif((nope.eq.10).or.(nope.eq.4)) then
 c             if(iperturb(1).eq.0) then
              if((iperturb(1).ne.1).and.(iperturb(2).ne.1)) then
@@ -1225,6 +1210,22 @@ c             if(iperturb(1).eq.0) then
                 enddo
              endif
           else
+!
+!         ---------------------------------------------------------
+!         variation of xl2 and xl1 (thets) for sensitivity analysis
+!         ---------------------------------------------------------
+!
+          if(idesva.gt.0) then
+             do i=1,nopes
+                iactnod=konl(ifacet(i,ig))
+                if(iactnod.eq.nodedesi(idesva)) then
+                   xl2(ndirdesi(idesva),i)=
+     &                  xl2(ndirdesi(idesva),i)+distmin
+                   exit
+                endif
+             enddo
+          endif
+
 c             if(iperturb(1).eq.0) then
              if((iperturb(1).ne.1).and.(iperturb(2).ne.1)) then
                 do i=1,nopes
@@ -1249,6 +1250,21 @@ c             if(iperturb(1).eq.0) then
              endif
           endif
 !
+!         ---------------------------------------------------------
+!         variation of xl2 and xl1 (wedge) for sensitivity analysis
+!         ---------------------------------------------------------
+!
+          if(idesva.gt.0) then
+             do i=1,nopes
+                iactnod=konl(ifacew(i,ig))
+                if(iactnod.eq.nodedesi(idesva)) then
+                   xl2(ndirdesi(idesva),i)=
+     &                  xl2(ndirdesi(idesva),i)+distmin
+                   exit
+                endif
+             enddo
+          endif
+!     
           do i=1,mint2d
              if((lakonl(4:5).eq.'8R').or.
      &            ((lakonl(4:4).eq.'6').and.(nopes.eq.4))) then
@@ -1256,7 +1272,7 @@ c             if(iperturb(1).eq.0) then
                 et=gauss2d1(2,i)
                 weight=weight2d1(i)
              elseif((lakonl(4:4).eq.'8').or.
-     &              (lakonl(4:6).eq.'20R').or.(lakonl(4:6).eq.'26R').or.
+     &              (lakonl(4:6).eq.'20R').or.
      &              ((lakonl(4:5).eq.'15').and.(nopes.eq.8))) then
                 xi=gauss2d2(1,i)
                 et=gauss2d2(2,i)
@@ -1265,7 +1281,7 @@ c             if(iperturb(1).eq.0) then
                 xi=gauss2d3(1,i)
                 et=gauss2d3(2,i)
                 weight=weight2d3(i)
-             elseif((lakonl(4:5).eq.'10').or.(lakonl(4:5).eq.'14').or.
+             elseif((lakonl(4:5).eq.'10').or.
      &               ((lakonl(4:5).eq.'15').and.(nopes.eq.6))) then
                 xi=gauss2d5(1,i)
                 et=gauss2d5(2,i)
@@ -1355,7 +1371,7 @@ c                   write(*,*) 'e_c3d ',(stress(k),k=1,6)
 !
                 do k=1,nopes
 c    Bernhardi start
-                   if((nope.eq.26).or.(nope.eq.20).or.(nope.eq.8).or.
+                   if((nope.eq.20).or.(nope.eq.8).or.
      &                (nope.eq.11)) then
 c    Bernhardi end
                       ipointer=(ifaceq(k,ig)-1)*3
@@ -1464,24 +1480,22 @@ c                   write(*,*) 'e_c3d ',(stress(k),k=1,6)
 !
                 do ii=1,nopes
 c     Bernhardi start
-                   if((nope.eq.26).or.(nope.eq.20).or.(nope.eq.8).or.
+                   if((nope.eq.20).or.(nope.eq.8).or.
      &                (nope.eq.11)) then
 c     Bernhardi end
                       ipointeri=(ifaceq(ii,ig)-1)*3
-                   elseif((nope.eq.10).or.(nope.eq.4).or.
-     &                    (nope.eq.14))then
+                   elseif((nope.eq.10).or.(nope.eq.4))then
                      ipointeri=(ifacet(ii,ig)-1)*3
                    else
                       ipointeri=(ifacew(ii,ig)-1)*3
                    endif
                    do jj=1,nopes
 c     Bernhardi start
-                      if((nope.eq.26).or.(nope.eq.20).or.(nope.eq.8)
+                      if((nope.eq.20).or.(nope.eq.8)
      &                 .or.(nope.eq.11)) then
 c     Bernhardi end
                          ipointerj=(ifaceq(jj,ig)-1)*3
-                      elseif((nope.eq.10).or.(nope.eq.4).or.
-     &                       (nope.eq.14)) then
+                      elseif((nope.eq.10).or.(nope.eq.4)) then
                          ipointerj=(ifacet(jj,ig)-1)*3
                       else
                          ipointerj=(ifacew(jj,ig)-1)*3
@@ -1632,18 +1646,18 @@ c     Bernhardi end
             summ=summ+sm(i,i)
          enddo
 !
-         if((nope.eq.26).or.(nope.eq.20)) then
+         if(nope.eq.20) then
 c            alp=.2215d0
             alp=.2917d0
 !              maybe alp=.2917d0 is better??
-         elseif((nope.eq.10).or.(nope.eq.14)) then
+         elseif(nope.eq.10) then
             alp=0.1203d0
          elseif(nope.eq.15) then
             alp=0.2141d0
          endif
 !
-         if((nope.eq.26).or.(nope.eq.20).or.(nope.eq.10).or.
-     &      (nope.eq.15).or.(nope.eq.14)) then
+         if((nope.eq.20).or.(nope.eq.10).or.
+     &      (nope.eq.15)) then
             factore=summass*alp/(1.d0+alp)/sume
             factorm=summass/(1.d0+alp)/summ
          else
@@ -1666,7 +1680,7 @@ c            alp=.2215d0
 !     Assigning the element stiffness matrix and the external load 
 !     vector to the corresponding matrices/vectors
 !     
-      if(desvar.eq.0) then
+      if(idesva.eq.0) then
 !     Stiffness matrix
          do i=1,3*nope
             do j=1,3*nope
@@ -1686,26 +1700,26 @@ c            alp=.2215d0
          enddo
          do i=1,3*nope
             l=0
-            ds(desvar,i)=0.d0
+            ds(idesva,i)=0.d0
             do j=1,nope
                do k=1,3
                   l=l+1
                   if ((l.eq.i).or.(l.gt.i)) then
-                     ds(desvar,i)=ds(desvar,i)+ds1(i,l)*voldl(k,j)
+                     ds(idesva,i)=ds(idesva,i)+ds1(i,l)*voldl(k,j)
                   else
-                     ds(desvar,i)=ds(desvar,i)+ds1(l,i)*voldl(k,j)
+                     ds(idesva,i)=ds(idesva,i)+ds1(l,i)*voldl(k,j)
                   endif
                enddo
             enddo
          enddo
 !     load vector
          do i=1,3*nope
-            dff(desvar,i)=(ff(i)-ff0(i))/distmin
+            dff(idesva,i)=(ff(i)-ff0(i))/distmin
          enddo
       endif
 !     
       do i=1,3*nope
-         dfminds(desvar,i)=dff(desvar,i)-ds(desvar,i)
+         dfminds(idesva,i)=dff(idesva,i)-ds(idesva,i)
       enddo
       
       enddo
