@@ -409,6 +409,8 @@ void getglobalresults (char *jobnamec,ITG **integerglobp,double **doubleglobp,
 	    nodenr=node[i].nr;
 	    field[13*(nodenr-1)]=lcase[loadcase].dat[0][nodenr];
 	}
+    }else{
+	printf("INFO in getglobalresults: no temperature data\n was found for step %d in the global model\n\n",istep);
     }
     
     /* reading the displacements */
@@ -450,6 +452,8 @@ void getglobalresults (char *jobnamec,ITG **integerglobp,double **doubleglobp,
 	    field[13*(nodenr-1)+2]=lcase[loadcase].dat[1][nodenr];
 	    field[13*(nodenr-1)+3]=lcase[loadcase].dat[2][nodenr];
 	}
+    }else{
+	printf("INFO in getglobalresults: no displacement data\n was found for step %d in the global model\n\n",istep);
     }
     
     /* reading the stresses */
@@ -493,6 +497,8 @@ void getglobalresults (char *jobnamec,ITG **integerglobp,double **doubleglobp,
 	    field[13*(nodenr-1)+8]=lcase[loadcase].dat[4][nodenr];
 	    field[13*(nodenr-1)+9]=lcase[loadcase].dat[5][nodenr];
 	}
+    }else{
+	printf("INFO in getglobalresults: no stress data\n was found for step %d in the global model\n\n",istep);
     }
     
     /* reading the forces */
@@ -532,6 +538,8 @@ void getglobalresults (char *jobnamec,ITG **integerglobp,double **doubleglobp,
 	    field[13*(nodenr-1)+11]=lcase[loadcase].dat[1][nodenr];
 	    field[13*(nodenr-1)+12]=lcase[loadcase].dat[2][nodenr];
 	}
+    }else{
+	printf("INFO in getglobalresults: no force data\n was found for step %d in the global model\n\n",istep);
     }
     
     SFREE(kontet);SFREE(inodfa);
