@@ -41,8 +41,8 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
   ITG i,j,k,l,jj,ll,id,index,jdof1,jdof2,idof1,idof2,mpc1,mpc2,id1,id2,
     ist1,ist2,node1,node2,isubtract,nmast,ifree,istart,istartold,
     index1,index2,m,node,nzs_,ist,kflag,indexe,nope,isize,*mast1=NULL,
-    *irow=NULL,icolumn,nmastboun,mt=mi[1]+1,jmax,*next=NULL,nopeold,
-    indexeold,identical;
+    *irow=NULL,icolumn,nmastboun,mt=mi[1]+1,jmax,*next=NULL,nopeold=0,
+      indexeold=0,identical,jstart;
 
   /* the indices in the comments follow FORTRAN convention, i.e. the
      fields start with 1 */
@@ -609,6 +609,14 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
        - jq(i)= location in field irow of the first SUBdiagonal
          nonzero in column i  */
 
+    /* subdiagonal elements of the regular stiffness/mass matrices
+       (marked by X underneath) */ 
+
+//               |x x x
+//        X      |x x x
+//        X X    |x x x
+//        X X X  |x x x
+
     RENEW(irow,ITG,ifree);
     nmast=0;
     jq[0]=1;
@@ -620,17 +628,9 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	    index=next[index-1];
 	}while(1);
 	jq[i+1]=nmast+1;
-	icol[i]=jq[i+1]-jq[i];
+//	icol[i]=jq[i+1]-jq[i];
     }
 
-    /* summary */
-
-    printf(" number of equations\n");
-    printf(" %" ITGFORMAT "\n",neq[1]);
-    printf(" number of nonzero lower triangular matrix elements\n");
-    printf(" %" ITGFORMAT "\n",nmast);
-    printf("\n");
-
     /* sorting the row numbers within each column */
 
     for(i=0;i<neq[1];++i){
@@ -640,12 +640,46 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	}
     }
 
+    /* removing duplicate entries */
+
+    nmast=0;
+    for(i=0;i<neq[1];i++){
+	jstart=nmast+1;
+	if(jq[i+1]-jq[i]>0){
+	    irow[nmast++]=irow[jq[i]-1];
+	    for(j=jq[i];j<jq[i+1]-1;j++){
+		if(irow[j]==irow[nmast-1])continue;
+		irow[nmast++]=irow[j];
+	    }
+	}
+	jq[i]=jstart;
+    }
+    jq[neq[1]]=nmast+1;
+
+    for(i=0;i<neq[1];i++){
+	icol[i]=jq[i+1]-jq[i];
+    }
+
     if(neq[0]==0){nzs[0]=0;}
     else{nzs[0]=jq[neq[0]]-1;}
     nzs[1]=jq[neq[1]]-1;
 
+    /* summary */
+
+    printf(" number of equations\n");
+    printf(" %" ITGFORMAT "\n",neq[1]);
+    printf(" number of nonzero lower triangular matrix elements\n");
+    printf(" %" ITGFORMAT "\n",nmast);
+    printf("\n");
+
     /* determining irow, jq and icol for the boundary stiffness matrix (only
-       for frequency and modal dynamic calculations */
+       for frequency and modal dynamic calculations) 
+       (entries marked by X underneath) */
+
+//               |X X X
+//        x      |X X X
+//        x x    |X X X
+//        x x x  |X X X
 
     if((*nmethod==2)||((*nmethod==4)&&(*iperturb<=1))||((*nmethod>=5)&&(*nmethod<=7))){
 
@@ -655,11 +689,10 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 	    do{
 		if(index==0) break;
 		irow[nmastboun++]=mast1[index-1];
-//		if(i==720) printf("mastruct i=%d,index=%d,idof1=%d\n",i,index,mast1[index-1]);
 		index=next[index-1];
 	    }while(1);
 	    jq[i+1]=nmastboun+1;
-	    icol[i]=jq[i+1]-jq[i];
+//	    icol[i]=jq[i+1]-jq[i];
 	}
 
 	/* sorting the row numbers within each column */
@@ -670,24 +703,38 @@ void mastruct(ITG *nk, ITG *kon, ITG *ipkon, char *lakon, ITG *ne,
 		FORTRAN(isortii,(&irow[jq[i]-1],&mast1[jq[i]-1],&isize,&kflag));
 	    }
 	}
+
+	/* removing duplicate entries */
+
+	nmastboun=nmast;
+	for(i=neq[1];i<neq[2];i++){
+	    jstart=nmastboun+1;
+	    if(jq[i+1]-jq[i]>0){
+		irow[nmastboun++]=irow[jq[i]-1];
+		for(j=jq[i];j<jq[i+1]-1;j++){
+		    if(irow[j]==irow[nmastboun-1])continue;
+		    irow[nmastboun++]=irow[j];
+		}
+	    }
+	    jq[i]=jstart;
+	}
+	jq[neq[2]]=nmastboun+1;
+	
+	for(i=neq[1];i<neq[2];i++){
+	    icol[i]=jq[i+1]-jq[i];
+	}
+
+        /* number of nonzero's in the boundary part*/
+
 	nzs[2]=jq[neq[2]]-1;
     }
     else{nzs[2]=nzs[1];}
 
-    /* for(i=0;i<nzs[2];i++){
-      printf("i=%" ITGFORMAT ",irow[i]=%" ITGFORMAT  "\n",i+1,irow[i]);
-  }
-  for(i=0;i<neq[2]+1;i++){
-      printf("i=%" ITGFORMAT ",jq[i]=%" ITGFORMAT "\n",i+1,jq[i]);
-      }*/
-
   SFREE(next);
 
   *mast1p=mast1;
   *irowp=irow;
 
-  /*for(i=0;i<4**nk;++i){printf("nactdof=%" ITGFORMAT ",%" ITGFORMAT "\n",i,nactdof[i]);}*/
-
   return;
 
 }
