@@ -38,7 +38,7 @@
       integer mi(*),itg(*),ieg(*),ntg,nteq,nflow,nload,
      &     ielmat(mi(3),*),iflag,ider,iaxial,
      &     nelemload(2,*),nope,nopes,mint2d,i,j,k,l,nrhcon(*),
-     &     node,imat,ntmat_,id,ifaceq(9,6),ifacet(7,4),numf,
+     &     node,imat,ntmat_,id,ifaceq(8,6),ifacet(6,4),numf,
      &     ifacew(8,5),node1,node2,nshcon(*),nelem,ig,index,konl(20),
      &     ipkon(*),kon(*),idof,ineighe(*),idir,
      &     iinc,istep,jltyp,nfield,ikforc(*),ipobody(2,*),
@@ -62,16 +62,16 @@
 !     
       include "gauss.f"
 !     
-      data ifaceq /4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/
-      data ifacet /1,3,2,7,6,5,11,
-     &     1,2,4,5,9,8,12,
-     &     2,3,4,6,10,9,13,
-     &     1,4,3,8,10,7,14/
+      data ifaceq /4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/
+      data ifacet /1,3,2,7,6,5,
+     &     1,2,4,5,9,8,
+     &     2,3,4,6,10,9,
+     &     1,4,3,8,10,7/
       data ifacew /1,3,2,9,8,7,0,0,
      &     4,5,6,10,11,12,0,0,
      &     1,2,5,4,7,14,10,13,
