@@ -42,7 +42,7 @@
       integer ntie,i,j,k,l,nset,istartset(*),iendset(*),ialset(*),
      &  ifaces,nelems,jfaces,ifacem,nelemm,nslavs,nmasts,jface,
      &  jfacem,indexe,nopes,nopem,ipkon(*),kon(*),id,nodef(9),
-     &  ifaceq(9,6),ifacet(7,4),ifacew1(4,5),ifacew2(8,5),node,
+     &  ifaceq(8,6),ifacet(6,4),ifacew1(4,5),ifacew2(8,5),node,
      &  itiefac(2,*),islavsurf(2,*),islavnode(*),imastnode(*),
      &  nslavnode(ntie+1),nmastnode(ntie+1),ifacecount,islav,imast,
      &  ipos,index1,iponoels(*),inoels(2,*),ifreenoels,ifreenoelold,
@@ -60,19 +60,19 @@
 !
 !     nodes per face for hex elements
 !
-      data ifaceq /4,3,2,1,11,10,9,12,21,
-     &            5,6,7,8,13,14,15,16,22,
-     &            1,2,6,5,9,18,13,17,23,
-     &            2,3,7,6,10,19,14,18,24,
-     &            3,4,8,7,11,20,15,19,25,
-     &            4,1,5,8,12,17,16,20,26/
+      data ifaceq /4,3,2,1,11,10,9,12,
+     &            5,6,7,8,13,14,15,16,
+     &            1,2,6,5,9,18,13,17,
+     &            2,3,7,6,10,19,14,18,
+     &            3,4,8,7,11,20,15,19,
+     &            4,1,5,8,12,17,16,20/
 !
 !     nodes per face for tet elements
 !
-      data ifacet /1,3,2,7,6,5,11,
-     &             1,2,4,5,9,8,12,
-     &             2,3,4,6,10,9,13,
-     &             1,4,3,8,10,7,14/
+      data ifacet /1,3,2,7,6,5,
+     &             1,2,4,5,9,8,
+     &             2,3,4,6,10,9,
+     &             1,4,3,8,10,7/
 !
 !     nodes per face for linear wedge elements
 !
@@ -401,14 +401,10 @@
 !
                   if(lakon(nelems)(4:5).eq.'20') then
                       nopes=8
-                  elseif(lakon(nelems)(4:4).eq.'2') then
-                      nopes=9
                   elseif(lakon(nelems)(4:4).eq.'8') then
                       nopes=4
                   elseif(lakon(nelems)(4:5).eq.'10') then
                       nopes=6
-                  elseif(lakon(nelems)(4:5).eq.'14') then
-                      nopes=7
                   elseif(lakon(nelems)(4:4).eq.'4') then
                       nopes=3
                   endif
@@ -538,14 +534,10 @@
 !     
                if(lakon(nelemm)(4:5).eq.'20') then
                   nopem=8
-               elseif(lakon(nelemm)(4:4).eq.'2') then
-                  nopem=9
                elseif(lakon(nelemm)(4:4).eq.'8') then
                   nopem=4
                elseif(lakon(nelemm)(4:5).eq.'10') then
                   nopem=6
-               elseif(lakon(nelemm)(4:5).eq.'14') then
-                  nopem=7
                elseif(lakon(nelemm)(4:4).eq.'4') then
                   nopem=3
                endif
